.. currentmodule:: obspy.io.segy
.. automodule:: obspy.io.segy

    .. comment to end block

    Classes & Functions
    -------------------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       ~header.TRACE_HEADER_FORMAT

    .. comment to end block

    Modules
    -------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       core
       segy
       util
       header
       pack
       unpack

    .. comment to end block
